inline void OFoldStream::setTrailingBlanks(TrailingBlanks tb)
{
    OFoldBuf::setTrailingBlanks(tb);
}
